changeset 39:571e34f3052c octave-forge

automate ChangeLog generation and release file upload.
author pkienzle
date Fri, 02 Nov 2001 18:11:19 +0000
parents 5e8b13e85fa7
children bcd452394004
files release.sh
diffstat 1 files changed, 28 insertions(+), 10 deletions(-) [+]
line wrap: on
line diff
--- a/release.sh	Fri Nov 02 17:10:24 2001 +0000
+++ b/release.sh	Fri Nov 02 18:11:19 2001 +0000
@@ -1,16 +1,22 @@
 # !/bin/sh
 
 ## Run this command to build a new release tarball. This assumes that 
 ## the CVSROOT environment variable has been set appropriately, and 
 ## that autogen is available on your path.
 ##
-## Next follow these instructions to perform the upload: 
-##	1. FTP to upload.sourceforge.net 
-## 	2. Login as "anonymous" 
-##	3. Use your e-mail address as the password for this login 
-##	4. Set your client to binary mode ("bin" on command-line clients) 
-##	5. Change your current directory to /incoming ("cd /incoming") 
-##	6. Upload the desired files for the release ("put filename") 
+## Define the following in ~/.netrc:
+##      machine upload.sf.net
+##      login anonymous
+##      password username@users.sf.net
+##      macdef init
+##         bin
+##         cd incoming
+##         mput octave-forge-*
+##         bye
+##      <leave this line empty!!>
 ##
 ## Finally, log in to your source forge account and use the following
 ## page to announce the new release of the package:
@@ -26,6 +32,12 @@
 TAG=R`date +%Y-%m-%d`
 ROOT=$PROJECT-`date +%Y.%m.%d`
 
+# generate the updated ChangeLog
+cvs2cl.pl --fsf --file ChangeLog.tmp
+echo "# Automatically generated file --- DO NOT EDIT" | cat - ChangeLog.tmp > ChangeLog
+rm ChangeLog.tmp
+cvs commit -m '$TAG release' ChangeLog
+
 # tag the CVS tree with the revision number
 cvs rtag $TAG $PROJECT
 
@@ -41,3 +53,9 @@
 # remove the tagged directory
 rm -rf $ROOT
 
+# optimistic: upload the file
+ftp upload.sf.net
+
+# display the ChangeLog so that you can generate a release description
+more ChangeLog
+
@@ -1,16 +1,22 @@
 # !/bin/sh
 
-## Run this command to build a new release tarball. This assumes that 
-## the CVSROOT environment variable has been set appropriately, and 
-## that autogen is available on your path.
+## Run this command from the project root directory to build a new 
+## release tarball. This assumes that the CVSROOT environment variable 
+## has been set appropriately, and that autogen is available on your path.
+## You will also need cvs2cl.pl from http://www.red-bean.com/cvs2cl/
+##
+## Don't forget 'cvs update' to make sure you haven't forgotten anything!
 ##